==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/it.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Condivisi con te",
    "Shared with others" : "Condivisi con altri",
    "Shared by link" : "Condivisi tramite collegamento",
    "Nothing shared with you yet" : "Non è stato condiviso ancora niente con te",
    "Files and folders others share with you will show up here" : "I file e le cartelle che altri condividono con te saranno mostrati qui",
    "Nothing shared yet" : "Ancora nessuna condivisione",
    "Files and folders you share will show up here" : "I file e le cartelle che condividi saranno mostrati qui",
    "No shared links" : "Nessun collegamento condiviso",
    "Files and folders you share by link will show up here" : "I file e le cartelle che condividi tramite collegamento saranno mostrati qui",
    "You can upload into this folder" : "Puoi caricare in questa cartella",
    "No compatible server found at {remote}" : "Nessun server compatibile trovato su {remote}",
    "Invalid server URL" : "URL del server non valido",
    "Failed to add the public link to your Nextcloud" : "Aggiunta del collegamento pubblico al tuo Nextcloud non riuscita",
    "Share" : "Condividi",
    "No expiration date set" : "Nessuna data di scadenza impostata",
    "Shared by" : "Condiviso da",
    "Sharing" : "Condivisione",
    "File shares" : "Condivisioni dei file",
    "Downloaded via public link" : "Scaricata tramite collegamento pubblico",
    "Downloaded by %1$s" : "Scaricato da %1$s",
    "Downloaded by {email}" : "Scaricato da {email}",
    "%1$s downloaded via public link" : "%1$s scaricato tramite collegamento pubblico",
    "{file} downloaded via public link" : "{file} scaricato tramite collegamento pubblico",
    "%1$s downloaded %2$s" : "%1$s ha scaricato %2$s",
    "{email} downloaded {file}" : "{email} ha scaricato {file}",
    "Shared with group %1$s" : "Condivisa con il gruppo %1$s",
    "Shared with group {group}" : "Condivisa con il gruppo {group}",
    "Removed share for group %1$s" : "Condivisione rimossa per %1$s",
    "Removed share for group {group}" : "Condivisione rimossa per il gruppo {group}",
    "%2$s shared with group %1$s" : "%2$s ha condiviso con il gruppo %1$s",
    "{actor} shared with group {group}" : "{actor} ha condiviso con il gruppo {group}",
    "%2$s removed share for group %1$s" : "%2$s ha rimosso la condivisione del gruppo %1$s",
    "{actor} removed share for group {group}" : "{actor} ha rimosso la condivisione del gruppo {group}",
    "You shared %1$s with group %2$s" : "Hai condiviso %1$s con il gruppo %2$s",
    "You shared {file} with group {group}" : "Hai condiviso {file} con il gruppo {group}",
    "You removed group %2$s from %1$s" : "Hai rimosso il gruppo %2$s da %1$s",
    "You removed group {group} from {file}" : "Hai rimosso il gruppo {group} da {file}",
    "%3$s shared %1$s with group %2$s" : "%3$s ha condiviso %1$s con il gruppo %2$s",
    "{actor} shared {file} with group {group}" : "{actor} ha condiviso {file} con il gruppo {group}",
    "%3$s removed group %2$s from %1$s" : "%3$s ha rimosso il gruppo %2$s da %1$s",
    "{actor} removed group {group} from {file}" : "{actor} ha ti rimosso il gruppo {group} da {file}",
    "Shared as public link" : "Condivisa tramite collegamento pubblico",
    "Removed public link" : "Collegamento pubblico rimosso",
    "%1$s shared as public link" : "%1$s condivisa tramite collegamento pubblico",
    "{actor} shared as public link" : "{actor} ha condiviso tramite collegamento pubblico",
    "%1$s removed public link" : "%1$s ha rimosso il collegamento pubblico",
    "{actor} removed public link" : "{actor} ha rimosso il collegamento pubblico",
    "You shared %1$s as public link" : "Hai condiviso %1$s tramite collegamento",
    "You shared {file} as public link" : "Hai condiviso {file} tramite collegamento",
    "You removed public link for %1$s" : "Hai rimosso il collegamento pubblico per %1$s",
    "You removed public link for {file}" : "Hai rimosso il collegamento pubblico per {file}",
    "%2$s shared %1$s as public link" : "%2$s ha condiviso %1$s tramite collegamento pubblico",
    "{actor} shared {file} as public link" : "{actor} ha condiviso {file} tramite collegamento pubblico",
    "%2$s removed public link for %1$s" : "%2$s ha rimosso il collegamento pubblico per %1$s",
    "{actor} removed public link for {file}" : "{actor} ha rimosso il collegamento pubblico per {file}",
    "%1$s accepted the remote share" : "%1$s ha accettato la condivisione remota",
    "{user} accepted the remote share" : "{user} ha accettato la condivisione remota",
    "%1$s declined the remote share" : "%1$s ha rifiutato la condivisione remota",
    "{user} declined the remote share" : "{user} ha rifiutato la condivisione remota",
    "You received a new remote share %1$s from %2$s" : "Hai ricevuto una nuova condivisione remota %1$s da %2$s",
    "You received a new remote share {file} from {user}" : "Hai ricevuto una nuova condivisione remota {file} da {user}",
    "%2$s accepted the remote share of %1$s" : "%2$s ha accettato la condivisione remota di %1$s",
    "{user} accepted the remote share of {file}" : "{user} ha accettato la condivisione remota di {file}",
    "%2$s declined the remote share of %1$s" : "%2$s ha rifiutato la condivisione remota %1$s",
    "{user} declined the remote share of {file}" : "{user} ha rifiutato la condivisione remota di {file}",
    "%2$s unshared %1$s from you" : "%2$s ha rimosso la condivisione %1$s con te",
    "{user} unshared {file} from you" : "{user} ha rimosso la condivisione {file} con te",
    "Shared with %1$s" : "Condivisa con %1$s",
    "Shared with {user}" : "Condivisa con {user}",
    "Removed share for %1$s" : "Condivisione rimossa per %1$s",
    "Removed share for {user}" : "Condivisione rimossa per {user}",
    "%2$s shared with %1$s" : "%2$s condivisa con %1$s",
    "{actor} shared with {user}" : "{actor} ha condiviso con {user}",
    "%2$s removed share for %1$s" : "%2$s ha rimosso la condivisione per %1$s",
    "{actor} removed share for {user}" : "{actor} ha rimosso la condivisione con {user}",
    "Shared by %1$s" : "Condivisa da %1$s",
    "Shared by {actor}" : "Condiviso da {actor}",
    "%1$s removed share" : "%1$s ha rimosso la condivisione",
    "{actor} removed share" : "{actor} ha rimosso la condivisione",
    "You shared %1$s with %2$s" : "Hai condiviso %1$s con %2$s",
    "You shared {file} with {user}" : "Hai condiviso {file} con {user}",
    "You removed %2$s from %1$s" : "Hai rimosso %2$s da %1$s",
    "You removed {user} from {file}" : "Hai rimosso {user} da {file}",
    "%3$s shared %1$s with %2$s" : "%3$s ha condiviso %1$s con %2$s",
    "{actor} removed {user} from {file}" : "{actor} ha rimosso {user} da {file}",
    "%3$s removed %2$s from %1$s" : "%3$s ha rimosso %2$s da %1$s",
    "%2$s shared %1$s with you" : "%2$s ha condiviso %1$s con te",
    "{actor} shared {file} with you" : "{actor} ha condiviso {file} con te",
    "%2$s removed you from %1$s" : "%2$s ti ha rimosso da %1$s",
    "{actor} removed you from {file}" : "{actor} ha ti rimosso da {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un file o una cartella condiviso via posta elettronica o collegamento pubblico è stato <strong>scaricato</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un file o una cartella è stato condiviso da <strong>un altro server</strong>",
    "A file or folder has been <strong>shared</strong>" : "Un file o una cartella è stato <strong>condiviso</strong>",
    "Wrong share ID, share doesn't exist" : "ID di condivisione errato, la condivisione non esiste",
    "could not delete share" : "impossibile eliminare la condivisione",
    "Could not delete share" : "impossibile eliminare la condivisione",
    "Please specify a file or folder path" : "Specifica un percorso di un file o di una cartella",
    "Wrong path, file/folder doesn't exist" : "Percorso errato, file/cartella inesistente",
    "Could not create share" : "Impossibile creare la condivisione",
    "invalid permissions" : "permessi non validi",
    "Please specify a valid user" : "Specifica un utente valido",
    "Group sharing is disabled by the administrator" : "La condivisione di gruppo è disabilitata dall'amministratore",
    "Please specify a valid group" : "Specifica un gruppo valido",
    "Public link sharing is disabled by the administrator" : "La condivisione pubblica di collegamenti è disabilitata dall'amministratore",
    "Public upload disabled by the administrator" : "Caricamento pubblico disabilitato dall'amministratore",
    "Public upload is only possible for publicly shared folders" : "Il caricamento pubblico è possibile solo per cartelle condivise pubblicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non valida, il formato della data deve essere YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Condivisione di %s non riuscita poiché il motore non consente condivisioni del tipo %s",
    "Unknown share type" : "Tipo di condivisione sconosciuto",
    "Not a directory" : "Non è una cartella",
    "Could not lock path" : "Impossibile bloccare il percorso",
    "Wrong or no update parameter given" : "Parametro fornito non valido o non di aggiornamento",
    "Can't change permissions for public share links" : "Impossibile cambiare i permessi per i collegamenti di condivisione pubblici",
    "Cannot increase permissions" : "Impossibile aumentare i permessi",
    "%s is publicly shared" : "%s è condiviso pubblicamente",
    "Share API is disabled" : "API di condivisione disabilitate",
    "This share is password-protected" : "Questa condivisione è protetta da password",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Password" : "Password",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Share time" : "Tempo di condivisione",
    "Expiration date" : "Data di scadenza",
    "Sorry, this link doesn’t seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
    "Reasons might be:" : "I motivi potrebbero essere:",
    "the item was removed" : "l'elemento è stato rimosso",
    "the link expired" : "il collegamento è scaduto",
    "sharing is disabled" : "la condivisione è disabilitata",
    "For more info, please ask the person who sent this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
    "Add to your Nextcloud" : "Aggiungi al tuo Nextcloud",
    "Download" : "Scarica",
    "Download %s" : "Scarica %s",
    "Direct link" : "Collegamento diretto",
    "Upload files to %s" : "Carica file su %s",
    "Select or drop files" : "Seleziona o deseleziona file",
    "Uploading files…" : "Caricamento file in corso...",
    "Uploaded files:" : "File caricati:",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un file condiviso pubblicamente o una cartella è stato <strong>scaricato</strong>",
    "You received a new remote share %2$s from %1$s" : "Hai ricevuto una nuova condivisione remota %2$s da %1$s",
    "You received a new remote share from %s" : "Hai ricevuto una nuova condivisione remota da %s",
    "%1$s accepted remote share %2$s" : "%1$s ha accettato la condivisione remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rifiutato la condivisione remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s ha rimosso la condivisione %2$s con te",
    "Public shared folder %1$s was downloaded" : "La cartella condivisa pubblicamente %1$s è stata scaricata",
    "Public shared file %1$s was downloaded" : "Il file condiviso pubblicamente %1$s è stato scaricato",
    "%2$s shared %1$s with %3$s" : "%2$s ha condiviso %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Hai rimosso la condivisione di %2$s per %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s ha rimosso la condivisione di %3$s per %1$s",
    "%2$s shared %1$s with group %3$s" : "%2$s ha condiviso %1$s con il gruppo %3$s",
    "You removed the share of group %2$s for %1$s" : "Hai rimosso la condivisione del gruppo %2$s per %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s ha rimosso la condivisione del gruppo %3$s per %1$s",
    "%2$s shared %1$s via link" : "%2$s ha condiviso %1$s tramite collegamento",
    "You shared %1$s via link" : "Hai condiviso %1$s tramite collegamento",
    "You removed the public link for %1$s" : "Hai rimosso il collegamento pubblico per %1$s",
    "%2$s removed the public link for %1$s" : "%2$s ha rimosso il collegamento pubblico per %1$s",
    "Your public link for %1$s expired" : "il tuo collegamento pubblico per %1$s è scaduto",
    "The public link of %2$s for %1$s expired" : "il collegamento pubblico di %2$s per %1$s è scaduto",
    "%2$s removed the share for %1$s" : "%2$s ha rimosso la condivisione per %1$s",
    "Shared with %2$s" : "Condivisa con %2$s",
    "Shared with %3$s by %2$s" : "Condivisa con %3$s da %2$s",
    "Removed share for %2$s" : "Condivisione rimossa per %2$s",
    "%2$s removed share for %3$s" : "%2$s ha rimosso la condivisione per %3$s",
    "Shared with group %2$s" : "Condivisa con il gruppo %2$s",
    "Shared with group %3$s by %2$s" : "Condivisa con il gruppo %3$s da %2$s",
    "Removed share of group %2$s" : "Condivisione rimossa del gruppo %2$s",
    "%2$s removed share of group %3$s" : "%2$s ha rimosso la condivisione del gruppo %3$s",
    "Shared via link by %2$s" : "Condivisa tramite collegamento da %2$s",
    "Shared via public link" : "Condivisa tramite collegamento pubblico",
    "%2$s removed public link" : "%2$s ha rimosso il collegamento pubblico",
    "Public link expired" : "Collegamento pubblico scaduto",
    "Public link of %2$s expired" : "il collegamento pubblico di %2$s è scaduto",
    "Shared by %2$s" : "Condivisa da %2$s",
    "Shares" : "Condivisioni"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/it.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Condivisi con te",
    "Shared with others" : "Condivisi con altri",
    "Shared by link" : "Condivisi tramite collegamento",
    "Nothing shared with you yet" : "Non è stato condiviso ancora niente con te",
    "Files and folders others share with you will show up here" : "I file e le cartelle che altri condividono con te saranno mostrati qui",
    "Nothing shared yet" : "Ancora nessuna condivisione",
    "Files and folders you share will show up here" : "I file e le cartelle che condividi saranno mostrati qui",
    "No shared links" : "Nessun collegamento condiviso",
    "Files and folders you share by link will show up here" : "I file e le cartelle che condividi tramite collegamento saranno mostrati qui",
    "You can upload into this folder" : "Puoi caricare in questa cartella",
    "No compatible server found at {remote}" : "Nessun server compatibile trovato su {remote}",
    "Invalid server URL" : "URL del server non valido",
    "Failed to add the public link to your Nextcloud" : "Aggiunta del collegamento pubblico al tuo Nextcloud non riuscita",
    "Share" : "Condividi",
    "No expiration date set" : "Nessuna data di scadenza impostata",
    "Shared by" : "Condiviso da",
    "Sharing" : "Condivisione",
    "File shares" : "Condivisioni dei file",
    "Downloaded via public link" : "Scaricata tramite collegamento pubblico",
    "Downloaded by {email}" : "Scaricato da {email}",
    "{file} downloaded via public link" : "{file} scaricato tramite collegamento pubblico",
    "{email} downloaded {file}" : "{email} ha scaricato {file}",
    "Shared with group {group}" : "Condivisa con il gruppo {group}",
    "Removed share for group {group}" : "Condivisione rimossa per il gruppo {group}",
    "{actor} shared with group {group}" : "{actor} ha condiviso con il gruppo {group}",
    "{actor} removed share for group {group}" : "{actor} ha rimosso la condivisione del gruppo {group}",
    "You shared {file} with group {group}" : "Hai condiviso {file} con il gruppo {group}",
    "You removed group {group} from {file}" : "Hai rimosso il gruppo {group} da {file}",
    "{actor} shared {file} with group {group}" : "{actor} ha condiviso {file} con il gruppo {group}",
    "{actor} removed group {group} from {file}" : "{actor} ha ti rimosso il gruppo {group} da {file}",
    "Shared as public link" : "Condivisa tramite collegamento pubblico",
    "Removed public link" : "Collegamento pubblico rimosso",
    "Public link expired" : "Collegamento pubblico scaduto",
    "{actor} shared as public link" : "{actor} ha condiviso tramite collegamento pubblico",
    "{actor} removed public link" : "{actor} ha rimosso il collegamento pubblico",
    "Public link of {actor} expired" : "Collegamento pubblico di {actor} scaduto",
    "You shared {file} as public link" : "Hai condiviso {file} tramite collegamento",
    "You removed public link for {file}" : "Hai rimosso il collegamento pubblico per {file}",
    "Public link expired for {file}" : "Collegamento pubblico scaduto per {file}",
    "{actor} shared {file} as public link" : "{actor} ha condiviso {file} tramite collegamento pubblico",
    "{actor} removed public link for {file}" : "{actor} ha rimosso il collegamento pubblico per {file}",
    "Public link of {actor} for {file} expired" : "Collegamento pubblico di {actor} per {file} scaduto",
    "{user} accepted the remote share" : "{user} ha accettato la condivisione remota",
    "{user} declined the remote share" : "{user} ha rifiutato la condivisione remota",
    "You received a new remote share {file} from {user}" : "Hai ricevuto una nuova condivisione remota {file} da {user}",
    "{user} accepted the remote share of {file}" : "{user} ha accettato la condivisione remota di {file}",
    "{user} declined the remote share of {file}" : "{user} ha rifiutato la condivisione remota di {file}",
    "{user} unshared {file} from you" : "{user} ha rimosso la condivisione {file} con te",
    "Shared with {user}" : "Condivisa con {user}",
    "Removed share for {user}" : "Condivisione rimossa per {user}",
    "{actor} shared with {user}" : "{actor} ha condiviso con {user}",
    "{actor} removed share for {user}" : "{actor} ha rimosso la condivisione con {user}",
    "Shared by {actor}" : "Condiviso da {actor}",
    "{actor} removed share" : "{actor} ha rimosso la condivisione",
    "You shared {file} with {user}" : "Hai condiviso {file} con {user}",
    "You removed {user} from {file}" : "Hai rimosso {user} da {file}",
    "{actor} shared {file} with {user}" : "{actor} ha condiviso {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} ha rimosso {user} da {file}",
    "{actor} shared {file} with you" : "{actor} ha condiviso {file} con te",
    "{actor} removed you from {file}" : "{actor} ha ti rimosso da {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un file o una cartella condiviso via posta elettronica o collegamento pubblico è stato <strong>scaricato</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un file o una cartella è stato condiviso da <strong>un altro server</strong>",
    "A file or folder has been <strong>shared</strong>" : "Un file o una cartella è stato <strong>condiviso</strong>",
    "Wrong share ID, share doesn't exist" : "ID di condivisione errato, la condivisione non esiste",
    "could not delete share" : "impossibile eliminare la condivisione",
    "Could not delete share" : "impossibile eliminare la condivisione",
    "Please specify a file or folder path" : "Specifica un percorso di un file o di una cartella",
    "Wrong path, file/folder doesn't exist" : "Percorso errato, file/cartella inesistente",
    "Could not create share" : "Impossibile creare la condivisione",
    "invalid permissions" : "permessi non validi",
    "Please specify a valid user" : "Specifica un utente valido",
    "Group sharing is disabled by the administrator" : "La condivisione di gruppo è disabilitata dall'amministratore",
    "Please specify a valid group" : "Specifica un gruppo valido",
    "Public link sharing is disabled by the administrator" : "La condivisione pubblica di collegamenti è disabilitata dall'amministratore",
    "Public upload disabled by the administrator" : "Caricamento pubblico disabilitato dall'amministratore",
    "Public upload is only possible for publicly shared folders" : "Il caricamento pubblico è possibile solo per cartelle condivise pubblicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non valida, il formato della data deve essere YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Condivisione di %s non riuscita poiché il motore non consente condivisioni del tipo %s",
    "You cannot share to a Circle if the app is not enabled" : "Non puoi condividere con una cerchia se l'applicazione non è abilitata",
    "Please specify a valid circle" : "Specifica una cerchia valida",
    "Unknown share type" : "Tipo di condivisione sconosciuto",
    "Not a directory" : "Non è una cartella",
    "Could not lock path" : "Impossibile bloccare il percorso",
    "Wrong or no update parameter given" : "Parametro fornito non valido o non di aggiornamento",
    "Can't change permissions for public share links" : "Impossibile cambiare i permessi per i collegamenti di condivisione pubblici",
    "Cannot increase permissions" : "Impossibile aumentare i permessi",
    "%s is publicly shared" : "%s è condiviso pubblicamente",
    "Share API is disabled" : "API di condivisione disabilitate",
    "File sharing" : "Condivisioni dei file",
    "This share is password-protected" : "Questa condivisione è protetta da password",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Password" : "Password",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Share time" : "Tempo di condivisione",
    "Expiration date" : "Data di scadenza",
    "Sorry, this link doesn’t seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
    "Reasons might be:" : "I motivi potrebbero essere:",
    "the item was removed" : "l'elemento è stato rimosso",
    "the link expired" : "il collegamento è scaduto",
    "sharing is disabled" : "la condivisione è disabilitata",
    "For more info, please ask the person who sent this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
    "Add to your Nextcloud" : "Aggiungi al tuo Nextcloud",
    "Download" : "Scarica",
    "Download %s" : "Scarica %s",
    "Direct link" : "Collegamento diretto",
    "Upload files to %s" : "Carica file su %s",
    "Select or drop files" : "Seleziona o deseleziona file",
    "Uploading files…" : "Caricamento file in corso...",
    "Uploaded files:" : "File caricati:"
},
"nplurals=2; plural=(n != 1);");
